import { Token, Recognizer, ParserErrorListener, RecognitionException } from 'antlr4ts';
import { ATNSimulator } from 'antlr4ts/atn/ATNSimulator';
export interface ParserError {
    startLine: number;
    endLine: number;
    startCol: number;
    endCol: number;
    message: string;
}
export interface SyntaxError<T> {
    recognizer: Recognizer<T, ATNSimulator>;
    offendingSymbol: Token;
    line: number;
    charPositionInLine: number;
    msg: string;
    e: RecognitionException;
}
export type ErrorHandler<T> = (err: ParserError, errOption: SyntaxError<T>) => void;
export declare class ParserErrorCollector implements ParserErrorListener {
    private _parseErrors;
    private _syntaxErrors;
    syntaxError(recognizer: Recognizer<Token, ATNSimulator>, offendingSymbol: Token, line: number, charPositionInLine: number, msg: string, e: RecognitionException): void;
    clear(): void;
    get parserErrors(): ParserError[];
}
export default class CustomParserErrorListener implements ParserErrorListener {
    private _errorHandler;
    constructor(errorListener: ErrorHandler<Token>);
    syntaxError(recognizer: Recognizer<Token, ATNSimulator>, offendingSymbol: Token, line: number, charPositionInLine: number, msg: string, e: RecognitionException): void;
}
