export class ParserErrorCollector {
    constructor() {
        this._parseErrors = [];
        this._syntaxErrors = [];
    }
    syntaxError(recognizer, offendingSymbol, line, charPositionInLine, msg, e) {
        let endCol = charPositionInLine + 1;
        if (offendingSymbol && offendingSymbol.text !== null) {
            endCol = charPositionInLine + offendingSymbol.text.length;
        }
        this._parseErrors.push({
            startLine: line,
            endLine: line,
            startCol: charPositionInLine,
            endCol: endCol,
            message: msg,
        });
        this._syntaxErrors.push({
            e,
            line,
            msg,
            recognizer,
            offendingSymbol,
            charPositionInLine,
        });
    }
    clear() {
        this._parseErrors = [];
        this._syntaxErrors = [];
    }
    get parserErrors() {
        return this._parseErrors;
    }
}
export default class CustomParserErrorListener {
    constructor(errorListener) {
        this._errorHandler = errorListener;
    }
    syntaxError(recognizer, offendingSymbol, line, charPositionInLine, msg, e) {
        let endCol = charPositionInLine + 1;
        if (offendingSymbol && offendingSymbol.text !== null) {
            endCol = charPositionInLine + offendingSymbol.text.length;
        }
        if (this._errorHandler) {
            this._errorHandler({
                startLine: line,
                endLine: line,
                startCol: charPositionInLine,
                endCol: endCol,
                message: msg,
            }, {
                e,
                line,
                msg,
                recognizer,
                offendingSymbol,
                charPositionInLine,
            });
        }
    }
}
//# sourceMappingURL=parserErrorListener.js.map